## Smart Signal Processing


### What the package can do for you
This package provides frequently used functions for signal processing:
- Computes mean values, variance, standard deviation.
- Applies windowing (apodization functions) with exponential or Gaussian shapes to an array
- Applies the Fast Fourier Transform to an array.
- Calculates the power or magnitude of a complex-valued array.
- Phase-shifts (rotates in the complex plane) a complex-valued array.


### The major API functionalities
 
- classes `Sigma`, `BaseLine`, `WinFunc`,`FFT`, `Phase`.



Examples: 

- Multiplication with an exponential:

  `WinFunc.expMult(array, decayFactor, false, "0");`
 
- Compute Fourier Transform:

  `FFT.transform(reals, imags);`

- Compute magnitude:

  `Phase.magnitude(reals, imags, true)`
  
- Compute variance in a region:  
  `Sigma.variance(array, ixstart, ixend)`
 


#### Detailed API
Please view the detailed API documentation in the `API` reference of this package (sidebar at the right of this page).


### Related packages

[`smart_arrays_base`: Basic functions for 1D and 2D arrays]( https://pub.dartlang.org/packages/smart_arrays_base)

[`smart_arrays_numerics`: Numerics with 1D and 2D arrays]( https://pub.dartlang.org/packages/smart_arrays_numerics)

[`smart_arrays_compress`: Compress 1D and 2D arrays to a smaller size.]( https://pub.dartlang.org/packages/smart_arrays_compress)

[`smart_arrays_peaks`: Detect peaks in 1D and 2D arrays.]( https://pub.dartlang.org/packages/smart_arrays_peaks)

[`smart_arrays_lmfit`: Fits (x, y) data given as arrays to a specified model function using the  Levenberg-Marquardt algorithm.]( https://pub.dartlang.org/packages/smart_arrays_lmfit)

[`smart_lorentz-gauss`: Compute Lorentz-Gauss (pseudo-Voigt) line shapes.]( https://pub.dartlang.org/packages/smart_lorentz-gauss)

[`smart_dialogs`: Easy-to-use dialogs in Web applications]( https://pub.dartlang.org/packages/smart_dialogs)
